import os
import random

from constants import *

from pygaze.display import Display
from pygaze.screen import Screen
from pygaze.keyboard import Keyboard
from pygaze.logfile import Logfile
from pygaze.eyetracker import EyeTracker
import pygaze.libtime as timer


# # # # #
# SETUP

# Initialise a new Display to
# communicate with the monitor.
disp = Display()

# Initialise a new Keyboard to
# catch keypresses.
kb = Keyboard()

# Initialise a new Logfile
log = Logfile()
log.write(['trialnr', 'trial', \
    'fixonset', 'imgonset', \
    'imgoffset'])

# Initialise a new EyeTracker to
# communicate with the eye tracker.
tracker = EyeTracker(disp)


# # # # #
# PRE-PREPARE SCREENS

# Create a blank screen.
blankscr = Screen()

# Create a screen with text.
txtscr = Screen()
txtscr.draw_text( \
    text="Press Space to start.", \
    fontsize=24)

# Create a fixation screen with a
# central fixation cross.
fixscr = Screen()
fixscr.draw_fixation(fixtype='cross', \
    pw=3)

# Start with an empty dict for the
# image screens.
imgscr = {}
# Loop through all the image file names.
for imgname in IMGNAMES:
    
    # Create a new Screen for this image.
    imgscr[imgname] = Screen()
    # Draw the image on the screen.
    imgscr[imgname].draw_image( \
        os.path.join(IMGDIR, imgname))


# # # # #
# RUN

# Get a list of all image names.
trials = imgscr.keys()
random.shuffle(trials)

# Calibrate the eye tracker.
tracker.calibrate()

# Loop through all images.
for trialnr, trial in enumerate(trials):
    
    # Show the text screen.
    disp.fill(txtscr)
    disp.show()
    # Wait for a key press.
    key, presstime = kb.get_key( \
        keylist=['space'], \
        timeout=None, \
        flush=True)
    
    # Start recording eye movements.
    tracker.start_recording()
    tracker.log("TRIALSTART")
    tracker.log("IMGNAME=%s" % imgname)
    
    # Show the fixation screen.
    disp.fill(fixscr)
    fixonset = disp.show()
    tracker.log("FIXONSET")
    timer.pause(2000)
    
    # Show the image screen.
    disp.fill(imgscr[trial])
    imgonset = disp.show()
    tracker.log("IMGONSET")
    timer.pause(5000)
    
    # Show a blank screen.
    disp.fill(blankscr)
    imgoffset = disp.show()
    tracker.log("IMGOFFSET")
    
    # Pause recording eye movements.
    tracker.stop_recording()
    
    # Write this trial into the
    # log file.
    log.write([trialnr, trial, \
        fixonset, imgonset, imgoffset])


# # # # #
# CLOSE

# Show a message.
txtscr.clear()
txtscr.draw_text( \
    text="Thanks for participating!", \
    fontsize=24)
disp.fill(txtscr)
disp.show()

# Close the log file.
log.close()

# Close the connection to the tracker.
tracker.close()

# Wait for a key press.
kb.get_key(keylist=None, \
    timeout=None, flush=True)

# Close the Display.
disp.close()
